GraphStoreServiceClient

Struct GraphStoreServiceClient 

pub struct GraphStoreServiceClient<T> { /* private fields */ }
/ Service for distributed graph store operations.

Implementations

Source

impl GraphStoreServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> GraphStoreServiceClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> GraphStoreServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn insert_node( &mut self, request: impl IntoRequest<InsertNodeRequest>, ) -> Result<Response<InsertNodeResponse>, Status>

Insert a node without a vector

pub async fn insert_node_with_vector( &mut self, request: impl IntoRequest<InsertNodeWithVectorRequest>, ) -> Result<Response<InsertNodeWithVectorResponse>, Status>

Insert a node with its embedding vector

pub async fn insert_nodes_with_vector( &mut self, request: impl IntoRequest<InsertNodesWithVectorRequest>, ) -> Result<Response<InsertNodesWithVectorResponse>, Status>

Batch insert nodes with their embedding vectors

pub async fn get_node( &mut self, request: impl IntoRequest<GetNodeRequest>, ) -> Result<Response<GetNodeResponse>, Status>

Get a node by its ID

pub async fn delete_node( &mut self, request: impl IntoRequest<DeleteNodeRequest>, ) -> Result<Response<DeleteNodeResponse>, Status>

Delete a node by its ID

pub async fn insert_edge( &mut self, request: impl IntoRequest<InsertEdgeRequest>, ) -> Result<Response<InsertEdgeResponse>, Status>

Insert an edge without a vector

pub async fn insert_edge_with_vector( &mut self, request: impl IntoRequest<InsertEdgeWithVectorRequest>, ) -> Result<Response<InsertEdgeWithVectorResponse>, Status>

Insert an edge with its embedding vector

pub async fn insert_edges_with_vector( &mut self, request: impl IntoRequest<InsertEdgesWithVectorRequest>, ) -> Result<Response<InsertEdgesWithVectorResponse>, Status>

Batch insert edges with their embedding vectors

pub async fn get_edge( &mut self, request: impl IntoRequest<GetEdgeRequest>, ) -> Result<Response<GetEdgeResponse>, Status>

Get an edge by its ID

pub async fn get_edges_for_node( &mut self, request: impl IntoRequest<GetEdgesForNodeRequest>, ) -> Result<Response<GetEdgesForNodeResponse>, Status>

Get all edges originating from a node

pub async fn get_edges_targeting_node( &mut self, request: impl IntoRequest<GetEdgesTargetingNodeRequest>, ) -> Result<Response<GetEdgesTargetingNodeResponse>, Status>

Get all edges targeting a node

pub async fn delete_edge( &mut self, request: impl IntoRequest<DeleteEdgeRequest>, ) -> Result<Response<DeleteEdgeResponse>, Status>

Delete an edge by its ID

pub async fn get_edge_vector( &mut self, request: impl IntoRequest<GetEdgeVectorRequest>, ) -> Result<Response<GetEdgeVectorResponse>, Status>

Get the embedding vector for an edge

pub async fn get_node_vector( &mut self, request: impl IntoRequest<GetNodeVectorRequest>, ) -> Result<Response<GetNodeVectorResponse>, Status>

Get the embedding vector for a node

pub async fn set_name_mapping( &mut self, request: impl IntoRequest<SetNameMappingRequest>, ) -> Result<Response<SetNameMappingResponse>, Status>

Set a name-to-node mapping for a given kind

pub async fn get_name_mapping( &mut self, request: impl IntoRequest<GetNameMappingRequest>, ) -> Result<Response<GetNameMappingResponse>, Status>

Get the node ID for a name mapping

pub async fn delete_name_mapping( &mut self, request: impl IntoRequest<DeleteNameMappingRequest>, ) -> Result<Response<DeleteNameMappingResponse>, Status>

Delete a name-to-node mapping

pub async fn search( &mut self, request: impl IntoRequest<SearchRequest>, ) -> Result<Response<SearchResponse>, Status>

Perform a vector similarity search over nodes and/or edges