pub struct EdgeWithVector {
pub edge: Option<Edge>,
pub vectors: Vec<f32>,
}Fields
edge: Option<Edge>vectors: Vec<f32>Trait Implementations
Sourceimpl Clone for EdgeWithVector
impl Clone for EdgeWithVector
Sourcefn clone(&self) -> EdgeWithVector
fn clone(&self) -> EdgeWithVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdgeWithVector
impl Debug for EdgeWithVector
Sourceimpl Default for EdgeWithVector
impl Default for EdgeWithVector
Sourceimpl<'de> Deserialize<'de> for EdgeWithVector
impl<'de> Deserialize<'de> for EdgeWithVector
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for EdgeWithVector
impl Message for EdgeWithVector
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EdgeWithVector
impl PartialEq for EdgeWithVector
Sourceimpl Serialize for EdgeWithVector
impl Serialize for EdgeWithVector
Sourceimpl TryFrom<EdgeWithVector> for EdgeWithVector
impl TryFrom<EdgeWithVector> for EdgeWithVector
Sourcetype Error = VecGraphError
type Error = VecGraphError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<EdgeWithVector> for EdgeWithVector
impl TryFrom<EdgeWithVector> for EdgeWithVector
Sourcetype Error = VecGraphError
type Error = VecGraphError
The type returned in the event of a conversion error.
impl StructuralPartialEq for EdgeWithVector